
.. _library:

=======
Library
=======

This section of the documentation deals with 
using the taurex library to construct your own
scripts!

.. toctree::
    :maxdepth: 3

    Quickstart <quickstart>